{ ... }: {
  imports = [
    ../../templates/proxmox-lxc.nix
    ../../server.nix
    ../../features/dns-cache.nix
  ];

  networking.hostName = "monitoring";
  system.stateVersion = "24.05";
  nixpkgs.hostPlatform = "x86_64-linux";

  services.grafana = {
    enable = true;
    settings = {
      server = {
        http_addr = "0.0.0.0";
        http_port = 3000;
        domain = "monitoring.hoki-porgy.ts.net";
      };
    };

    provision = {
      enable = true;
      datasources.settings.datasources = [
        {
          url = "http://localhost:4000";
          type = "prometheus";
          name = "Prometheus";
        }
      ];
    };
  };
  
  services.prometheus = {
    enable = true;
    port = 4000;
    
    scrapeConfigs = let
      static = name: ports: { 
        job_name = name;
        static_configs = [
          { 
            targets = map (port: "${name}.hoki-porgy.ts.net:${builtins.toString port}") ports;
          }
        ]; 
      };
      port = 14200;
    in [
      (static "aerial" [ port ])
      (static "pineapple" [ port (port + 1) ])
      (static "watermelon" [ port (port + 1) (port + 2) ])
      (static "mango" [ port ])
      (static "happystaticbuzz" [ port ])
      (static "keylime" [ port ])
      (static "keysmash" [ port ])
      (static "ingress-proxy" [ port ])
      {
        job_name = "pve1";
        static_configs = [
          { targets = [ "192.168.1.128:${builtins.toString port}" ]; }
        ];
      }
    ];
  };

}
